@@ -2,19 +2,20 @@
 use strict;
 use warnings;
 
-use Net::Frame::Dump qw(:consts);
+my $oDump;
+my $dev = shift || die("Specify network interface to use\n");
+
+use Net::Frame::Dump::Online;
 use Net::Frame::Simple;
+use Class::Gomor qw($Debug);
+$Debug = 3;
 
-my $d = Net::Frame::Dump->new(
-   dev  => $ARGV[0],
-   mode => NP_DUMP_MODE_ONLINE,
-);
-
-$d->start;
+$oDump = Net::Frame::Dump::Online->new(dev => $dev);
+$oDump->start;
 
 my $count = 0;
 while (1) {
-   if (my $h = $d->next) {
+   if (my $h = $oDump->next) {
       my $f = Net::Frame::Simple->new(
          raw        => $h->{raw},
          firstLayer => $h->{firstLayer},
@@ -26,12 +27,4 @@ while (1) {
    }
 }
 
-$d->stop;
-$d->clean;
-
-END {
-   if ($d && $d->isRunning) {
-      $d->stop;
-      $d->clean;
-   }
-}
+END { $oDump && $oDump->isRunning && $oDump->stop }
